==> far2l_2.6.0~beta+ds.orig.tar.xz: far2l-2.6.0~beta+ds/far2l/src/filemask/FileMasksProcessor.hpp <==
#pragma once

/*
FileMasksProcessor.hpp

Класс для работы с простыми масками файлов (не учитывается наличие масок
исключения).
*/
/*
Copyright (c) 1996 Eugene Roshal
Copyright (c) 2000 Far Group
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:
1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.
3. The name of the authors may not be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#include "BaseFileMask.hpp"
#include "udlist.hpp"
#include "RegExp.hpp"

enum FMP_FLAGS
{
	FMPF_ADDASTERISK = 0x00000001		// Добавлять '*', если маска не содержит
										// ни одного из следующих
										// символов: '*', '?', '.'
};

class FileMasksProcessor : public BaseFileMask
{
public:
	FileMasksProcessor();
	virtual ~FileMasksProcessor() { Free(); }

public:
	virtual bool Set(const wchar_t *Masks, DWORD Flags);
	virtual bool Compare(const wchar_t *Name) const;
	virtual bool IsEmpty() const;
	void Free();

private:
	UserDefinedList Masks;	// список масок файлов
	std::unique_ptr<RegExp> re;
	int n = 0;
};

==> far2l_2.6.3~beta+ds.orig.tar.xz: far2l-2.6.3~beta+ds/far2l/src/filemask/FileMasksProcessor.hpp <==
#pragma once

/*
FileMasksProcessor.hpp

Класс для работы с простыми масками файлов (не учитывается наличие масок
исключения).
*/
/*
Copyright (c) 1996 Eugene Roshal
Copyright (c) 2000 Far Group
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:
1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.
3. The name of the authors may not be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#include "BaseFileMask.hpp"
#include "udlist.hpp"
#include "RegExp.hpp"

enum FMP_FLAGS
{
	FMPF_ADDASTERISK = 0x00000001		// Добавлять '*', если маска не содержит
										// ни одного из следующих
										// символов: '*', '?', '.'
};

class FileMasksProcessor : public BaseFileMask
{
public:
	FileMasksProcessor();
	virtual ~FileMasksProcessor() { Free(); }

public:
	virtual bool Set(const wchar_t *Masks, DWORD Flags);
	virtual bool Compare(const wchar_t *Name, bool ignorecase = true) const;
	virtual bool IsEmpty() const;
	void Free();

private:
	UserDefinedList Masks;	// список масок файлов
	std::unique_ptr<RegExp> re;
	int n = 0;
};
